package com.ynet.life.security.crypto;

import java.io.BufferedOutputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.security.SecureRandom;
import javax.crypto.Cipher;
import javax.crypto.KeyGenerator;
import javax.crypto.SecretKey;
import javax.crypto.SecretKeyFactory;
import javax.crypto.spec.DESKeySpec;
import javax.crypto.spec.SecretKeySpec;
import org.bouncycastle.util.encoders.Hex;

/* loaded from: com_ynet_life_security_crypto.jar:com/ynet/life/security/crypto/DESCrypto.class */
public class DESCrypto {
    private static final String DES = "DES";
    private static final String TRIPLE_DES = "TripleDES";
    private static final String DES_KEY_FILE = "C:\\des.key";
    private static final String TRIPLE_DES_KEY_FILE = "C:\\tripledes.key";
    public static DESKeySpec DESKeySpec;
    public static SecretKeySpec tripleDESKeySpec;

    public static DESKeySpec getDESKeySpec() throws IOException, NoSuchAlgorithmException, InvalidKeyException {
        byte[] bytes = new byte[8];
        File f = new File(DES_KEY_FILE);
        if (f.exists()) {
            new FileInputStream(f).read(bytes);
        } else {
            KeyGenerator kgen = KeyGenerator.getInstance(DES);
            kgen.init(56);
            bytes = kgen.generateKey().getEncoded();
            new FileOutputStream(f).write(bytes);
        }
        return new DESKeySpec(bytes);
    }

    public static SecretKeySpec getTripleDESKeySpec() throws IOException, NoSuchAlgorithmException {
        byte[] bytes = new byte[24];
        File f = new File(TRIPLE_DES_KEY_FILE);
        if (f.exists()) {
            new FileInputStream(f).read(bytes);
        } else {
            KeyGenerator kgen = KeyGenerator.getInstance(TRIPLE_DES);
            kgen.init(168);
            bytes = kgen.generateKey().getEncoded();
            new FileOutputStream(f).write(bytes);
        }
        return new SecretKeySpec(bytes, TRIPLE_DES);
    }

    public static DESKeySpec getDESKeySpecFromString(String strKey) throws NoSuchAlgorithmException, InvalidKeyException {
        return new DESKeySpec(strKey.getBytes());
    }

    public static DESKeySpec getDESKeySpecFromBytes(String strBytes) throws NoSuchAlgorithmException, InvalidKeyException {
        return new DESKeySpec(Hex.decode(strBytes.getBytes()));
    }

    public static DESKeySpec getDESKeySpecFromOCString(String strKey) throws NoSuchAlgorithmException, InvalidKeyException, UnsupportedEncodingException {
        String strKeyString = new String(Hex.decode(strKey.getBytes()));
        return new DESKeySpec(strKeyString.getBytes());
    }

    public static SecretKeySpec getTripleDESKeySpecFromBytes(String strBytes) throws NoSuchAlgorithmException {
        return new SecretKeySpec(Hex.decode(strBytes.getBytes()), TRIPLE_DES);
    }

    public static SecretKeySpec getTripleDESKeySpecFromString(String strKey) throws NoSuchAlgorithmException {
        return new SecretKeySpec(strKey.getBytes(), "DESede");
    }

    public static SecretKeySpec getJSTripleDESKeySpecFromString(String strKey) throws NoSuchAlgorithmException {
        return new SecretKeySpec(strKey.getBytes(), TRIPLE_DES);
    }

    public static String getDESKeyString() {
        return new String(Hex.encode(DESKeySpec.getKey()));
    }

    public static String getTripleDESKeyString() {
        return new String(Hex.encode(tripleDESKeySpec.getEncoded()));
    }

    public static byte[] encrypt(byte[] src) throws Exception {
        SecureRandom sr = new SecureRandom();
        SecretKey securekey = SecretKeyFactory.getInstance(DES).generateSecret(DESKeySpec);
        Cipher cipher = Cipher.getInstance(DES);
        cipher.init(1, securekey, sr);
        return cipher.doFinal(src);
    }

    public static byte[] tripleDESEncrypt(byte[] src) throws Exception {
        Cipher cipher = Cipher.getInstance(TRIPLE_DES);
        cipher.init(1, tripleDESKeySpec);
        return cipher.doFinal(src);
    }

    public static byte[] decrypt(byte[] src) throws Exception {
        SecureRandom sr = new SecureRandom();
        SecretKey securekey = SecretKeyFactory.getInstance(DES).generateSecret(DESKeySpec);
        Cipher cipher = Cipher.getInstance(DES);
        cipher.init(2, securekey, sr);
        return cipher.doFinal(src);
    }

    public static byte[] tripleDESDecrypt(byte[] src) throws Exception {
        Cipher cipher = Cipher.getInstance(TRIPLE_DES);
        cipher.init(2, tripleDESKeySpec);
        return cipher.doFinal(src);
    }

    /* JADX WARN: Type inference failed for: r0v2, types: [java.lang.String, java.lang.Exception] */
    public static final String encrypt(String src) {
        ?? str;
        try {
            str = new String(Hex.encode(encrypt(src.getBytes())));
            return str;
        } catch (Exception e) {
            str.printStackTrace();
            return null;
        }
    }

    /* JADX WARN: Type inference failed for: r0v2, types: [java.lang.String, java.lang.Exception] */
    public static final String tripleDESEncrypt(String src) {
        ?? str;
        try {
            str = new String(Hex.encode(tripleDESEncrypt(src.getBytes())));
            return str;
        } catch (Exception e) {
            str.printStackTrace();
            return null;
        }
    }

    /* JADX WARN: Type inference failed for: r0v2, types: [java.lang.String, java.lang.Exception] */
    public static final String decrypt(String src) {
        ?? str;
        try {
            str = new String(decrypt(Hex.decode(src.getBytes())));
            return str;
        } catch (Exception e) {
            str.printStackTrace();
            return null;
        }
    }

    /* JADX WARN: Type inference failed for: r0v2, types: [java.lang.String, java.lang.Exception] */
    public static final String tripleDESDecrypt(String src) {
        ?? str;
        try {
            str = new String(tripleDESDecrypt(Hex.decode(src.getBytes())));
            return str;
        } catch (Exception e) {
            str.printStackTrace();
            return null;
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v1, types: [boolean] */
    /* JADX WARN: Type inference failed for: r0v17, types: [java.io.FileOutputStream] */
    /* JADX WARN: Type inference failed for: r0v2 */
    /* JADX WARN: Type inference failed for: r0v24, types: [java.lang.Exception] */
    /* JADX WARN: Type inference failed for: r0v26, types: [boolean] */
    /* JADX WARN: Type inference failed for: r0v27 */
    /* JADX WARN: Type inference failed for: r0v28 */
    /* JADX WARN: Type inference failed for: r0v29 */
    /* JADX WARN: Type inference failed for: r0v3, types: [java.lang.Exception] */
    public static File encryptFile(File file, String str, boolean z) {
        byte[] encrypt;
        File file2 = new File(str);
        ?? exists = file2.exists();
        ?? r0 = exists;
        if (exists == 0) {
            try {
                exists = file2.createNewFile();
                r0 = exists;
            } catch (Exception e) {
                exists.printStackTrace();
                r0 = exists;
            }
        }
        try {
            FileInputStream fileInputStream = new FileInputStream(file);
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream(fileInputStream.available());
            byte[] bArr = new byte[fileInputStream.available()];
            while (fileInputStream.read(bArr) != -1) {
                if (z) {
                    encrypt = tripleDESEncrypt(bArr);
                } else {
                    encrypt = encrypt(bArr);
                }
                byteArrayOutputStream.write(encrypt, 0, encrypt.length);
            }
            fileInputStream.close();
            byteArrayOutputStream.close();
            FileOutputStream fileOutputStream = new FileOutputStream(file2);
            BufferedOutputStream bufferedOutputStream = new BufferedOutputStream(fileOutputStream);
            bufferedOutputStream.write(byteArrayOutputStream.toByteArray());
            bufferedOutputStream.close();
            r0 = fileOutputStream;
            r0.close();
        } catch (Exception e2) {
            r0.printStackTrace();
        }
        return file2;
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v1, types: [boolean] */
    /* JADX WARN: Type inference failed for: r0v2, types: [java.lang.Exception] */
    /* JADX WARN: Type inference failed for: r0v21, types: [java.io.FileOutputStream] */
    /* JADX WARN: Type inference failed for: r0v28 */
    /* JADX WARN: Type inference failed for: r0v29 */
    /* JADX WARN: Type inference failed for: r0v30 */
    /* JADX WARN: Type inference failed for: r0v4, types: [boolean] */
    /* JADX WARN: Type inference failed for: r0v5 */
    /* JADX WARN: Type inference failed for: r0v6, types: [java.lang.Exception] */
    public static File decryptFile(File file, String str, boolean z) {
        byte[] decrypt;
        File file2 = new File(str);
        ?? exists = file2.exists();
        ?? r0 = exists;
        if (exists == 0) {
            try {
                exists = file2.createNewFile();
                r0 = exists;
            } catch (Exception e) {
                exists.printStackTrace();
                r0 = exists;
            }
        }
        try {
            FileInputStream fileInputStream = new FileInputStream(file);
            int available = fileInputStream.available() - (fileInputStream.available() % 8);
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream(available);
            byte[] bArr = new byte[available];
            while (fileInputStream.read(bArr) != -1) {
                if (z) {
                    decrypt = tripleDESDecrypt(bArr);
                } else {
                    decrypt = decrypt(bArr);
                }
                byteArrayOutputStream.write(decrypt, 0, decrypt.length);
            }
            fileInputStream.close();
            byteArrayOutputStream.close();
            FileOutputStream fileOutputStream = new FileOutputStream(file2);
            BufferedOutputStream bufferedOutputStream = new BufferedOutputStream(fileOutputStream);
            bufferedOutputStream.write(byteArrayOutputStream.toByteArray());
            bufferedOutputStream.close();
            r0 = fileOutputStream;
            r0.close();
        } catch (Exception e2) {
            r0.printStackTrace();
        }
        return file2;
    }

    public static String getRandomSuffix() {
        String strRandom = encrypt("        ");
        return strRandom.substring(strRandom.length() - 16);
    }

    public static String get3DESRandomSuffix() {
        String strRandom = tripleDESEncrypt("        ");
        System.out.println(strRandom);
        return strRandom.substring(strRandom.length() - 16);
    }

    public static void main(String[] args) {
    }
}
